# nucosObs
*nucosObs* serves as an observer-observable framework based on asyncio 

## Install
```
pip install nucosObs
```


## Documentation
not yet hosted 


## Licence
MIT License

## Platforms
No specific platform dependency. Python 3.5 is minimum.


